<?php
//$Id: SiteConfigureTest.php,v 1.1 2007/08/15 04:25:34 allisterbeharry Exp $
/**
 * @file
 * Simpletest unit test suite for SiteConfigure build script
 * @author Allister Beharry
 * @package org.drupal.dast.base
 */

require_once('dast_test_init.php');
require_once('SimpleBuildFileTest.php');
include_once('creole/Creole.php');

class SiteConfigureTest extends SimpleBuildFileTest {
  
  function __construct ()  {
    $this->UnitTestCase();
    define('BASE_PROPERTIES_FILE', PHING_TEST_BASE.DIRECTORY_SEPARATOR.'site-configure-base.properties');
    $this->configureProject(PHING_TEST_BASE.DIRECTORY_SEPARATOR.'site-configure.xml');
    //$this->executeTarget("main");
  }
  
  function __destruct() {
    Phing::shutdown();
  }

  public function setUp() { 

  }

  /**
   * Test that SimpleTest is working properly
   *
   */
  function testSanity() {
    $this->assertTrue(2==2, "assertTrue OK.");
    $this->assertPropertyEquals('build.testing', 'yes');
  }
  
  /**
   * Test that base properties are set
   *
   */
  function testBasePropertiesSet() {
    //echo BASE_PROPERTIES_FILE;
    $this->executeTarget("configure");
    $this->assertPropertyEquals('build.basePropertiesFile', BASE_PROPERTIES_FILE);
    $this->assertPropertyEquals('build.log.defaultdir', "E:\var\log");
    $this->assertPropertyEquals('drupal.dir', 'E:\Webs\ApacheDrupal\drupal52-dev\dast');
    $this->assertPropertyEquals('drupal.Url', 'http://localhost:8001/drupal52-dev/dast/');
    $this->assertPropertyEquals('drupal.database.driver', 'mysql');
    $this->assertPropertyEquals('drupal.database.host', 'localhost');
    $this->assertPropertyEquals('drupal.database.name', 'DRUPAL52');
    $this->assertPropertyEquals('drupal.database.user', 'joe');
    $this->assertPropertyEquals('drupal.database.user.pass', 'cool');
    $this->assertPropertyEquals('drupal.database.CreateScript', 'MYSQL5-CREATE-DRUPAL-DB.sql');
    $this->assertPropertyEquals('drupal.database.CreateScript.user', 'root');
    $this->assertPropertyEquals('drupal.database.CreateScript.user.pass', 'all!ster');
    $this->assertPropertyEquals('drupal.database.CreateScript.name', 'mysql');
    $this->assertPropertyEquals('drupal.database.Url', 'mysql://joe:cool@localhost/DRUPAL52');
    $this->assertPropertyEquals('drupal.database.CreateUrl', 'mysql://root:all!ster@localhost/mysql');
    
  }
  
  /**
   * Test the create-database task can copy the script file to the dast.tmp directory replacing the 
   * ${drupal.database.* tokens in the file with their property values from the build file, execute this test script,
   * successfully create the database and user, and then delete the temp file. 
   *
   */
  function testCreateDatabase() {
   $this->executeTarget("create-database");
   $this->assertTrue(file_exists(DAST_HOME.DIRECTORY_SEPARATOR.'tmp'.DIRECTORY_SEPARATOR.$this->project->getProperty("drupal.database.CreateScript")));
   $createscriptfile = DAST_HOME.DIRECTORY_SEPARATOR.'tmp'.DIRECTORY_SEPARATOR.$this->project->getProperty("drupal.database.CreateScript");
   $handle = fopen($createscriptfile, "r");
   $createscript = fread($handle, filesize($createscriptfile));
   fclose($handle);
   //$handle = fopen(DAST_TEST.DIRECTORY_SEPARATOR.'etc)
   //$this->assertTrue(strpos($createscript, ))
   
   unset($handle);
   
  }
  
  /**
   * Opens a connection to the database using the Creole library
   */
  protected function getConnection($url, $autocommit) {
    $conn = Creole::getConnection(Creole::parseDSN($url));
    $conn->setAutoCommit($autocommit);
    return $conn;           
    //Creole::registerDriver($dsn['phptype'], $this->driver);      
  }
  
  protected function configureProject($filename) { 
   //Init Phing project
   $this->logBuffer = "";
   $this->fullLogBuffer = "";
   $this->project = new Project();
   $this->project->init();
   $f = new PhingFile($filename);
   $this->project->setUserProperty( "phing.file" , $f->getAbsolutePath() );
   $this->project->setProperty('build.testing', 'yes'); //Inform the buld file we are running tests  
   
   //$this->project->setProperty('dast.home', DAST_HOME);
   //$this->project->setProperty('phing.home', DAST_HOME);
   //$this->project->setProperty('php.directory_separator', DIRECTORY_SEPARATOR);
   $this->project->setProperty('build.basePropertiesFile', BASE_PROPERTIES_FILE);
//   //Set base and custom properties
//   if ( PHP_OS == 'WINNT') {
//     $this->project->setProperty('build.basePropertiesFile', DAST_TEST.DIRECTORY_SEPARATOR.'etc'.DIRECTORY_SEPARATOR.'site-fetch-windows-test-base.properties');
//     $this->project->setProperty('build.PropertiesFile', DAST_TEST.DIRECTORY_SEPARATOR.'etc'.DIRECTORY_SEPARATOR.'site-fetch-windows-test.properties');
//   }
//   else {
//     $this->project->setProperty('build.basePropertiesFile', DAST_TEST.DIRECTORY_SEPARATOR.'etc'.DIRECTORY_SEPARATOR.'site-fetch-nix-test-base.properties');
//     $this->project->setProperty('build.PropertiesFile', DAST_TEST.DIRECTORY_SEPARATOR.'etc'.DIRECTORY_SEPARATOR.'site-fetch-nix-test.properties');
//   }
   $this->project->addBuildListener(new PhingTestListener($this));
   ProjectConfigurator::configureProject($this->project, $f);
   
  }  
    
 }